@@ -1233,7 +1233,9 @@ CreateInstanceAccessControlAttributeConfigurationRequestRequestTypeDef = TypedDi
     "CreateInstanceAccessControlAttributeConfigurationRequestRequestTypeDef",
     {
         "InstanceArn": str,
-        "InstanceAccessControlAttributeConfiguration": InstanceAccessControlAttributeConfigurationTypeDef,
+        "InstanceAccessControlAttributeConfiguration": (
+            InstanceAccessControlAttributeConfigurationTypeDef
+        ),
     },
 )
 
@@ -1242,7 +1244,9 @@ DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef = TypedDict(
     {
         "Status": InstanceAccessControlAttributeConfigurationStatusType,
         "StatusReason": str,
-        "InstanceAccessControlAttributeConfiguration": InstanceAccessControlAttributeConfigurationTypeDef,
+        "InstanceAccessControlAttributeConfiguration": (
+            InstanceAccessControlAttributeConfigurationTypeDef
+        ),
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -1251,6 +1255,8 @@ UpdateInstanceAccessControlAttributeConfigurationRequestRequestTypeDef = TypedDi
     "UpdateInstanceAccessControlAttributeConfigurationRequestRequestTypeDef",
     {
         "InstanceArn": str,
-        "InstanceAccessControlAttributeConfiguration": InstanceAccessControlAttributeConfigurationTypeDef,
+        "InstanceAccessControlAttributeConfiguration": (
+            InstanceAccessControlAttributeConfigurationTypeDef
+        ),
     },
 )
